@@ -3,9 +3,12 @@
 // [[Rcpp::export]]
 Rcpp::IntegerMatrix dilateImage(Rcpp::IntegerMatrix mat, int kernel, int niter) {
 
+	// ITERATING THROUGH MATRIX BY POINTER GOES DOWN COLUMNS FIRST, THEN BY ROW
+	// WILL ONLY WORK FOR BINARY IMAGES (RUNS FASTER WHEN VALUES CAN ONLY BE 0,1)
+	
 	if(niter == 0) return mat;
 
-	int i, j, k, it, max;
+	int i, j, k, it;
 	int nrow = mat.nrow();
 	int ncol = mat.ncol();
 
@@ -21,20 +24,16 @@ Rcpp::IntegerMatrix dilateImage(Rcpp::IntegerMatrix mat, int kernel, int niter)
 
 	// CREATE KERNEL VECTOR
 	int kernel_sq = kernel*kernel;
-	std::vector<int> kernel_vec(kernel_sq);
-	for(i = 0; i < kernel_sq; i++) kernel_vec[i] = (i % kernel) + (i/kernel)*nrow;
+	std::vector<int> k_vec(kernel_sq);
+	for(i = 0; i < kernel_sq; i++) k_vec[i] = (i % kernel) + (i/kernel)*nrow;
 
 	// GET HALF KERNEL
-	int half_kernel = (kernel / 2);
-	int	nrow_h = nrow-half_kernel;
-	int	ncol_h = ncol-half_kernel;
+	int half_k = (kernel / 2);
+	int	nrow_h = nrow-half_k;
+	int	ncol_h = ncol-half_k;
 
 	// GET MID KERNEL
-	int mid_kernel = (kernel_sq / 2);
-
-	// CREATE COLUMN VECTOR
-	std::vector<int> col_vec(ncol);
-	for(i = 0; i < ncol; i++) col_vec[i] = i*nrow;
+	int mid_k = (kernel_sq / 2);
 
 	for(it = 0; it < niter; it++){
 
@@ -43,24 +42,25 @@ Rcpp::IntegerMatrix dilateImage(Rcpp::IntegerMatrix mat, int kernel, int niter)
 		int lcol = ncol - kernel + 1;
 		for(i = 0; i < lrow; i++){
 			for(j = 0; j < lcol;j++){
-				max = 0;
 				for(k = 0; k < kernel_sq; k++){
-					if(*(mat_copy.begin() + i+col_vec[j] + kernel_vec[k]) > max) max = *(mat_copy.begin() + i+col_vec[j] + kernel_vec[k]);
+					if(*(mat_copy.begin() + i + j*nrow + k_vec[k]) == 1){
+						*(mat_max.begin() + i + j*nrow + k_vec[mid_k]) = 1;
+						break;
+					}
 				}
-				*(mat_max.begin() + i+col_vec[j] + kernel_vec[mid_kernel]) = max;
 			}
 		}
 
 		// SET MAX KERNEL VALUES ALONG TOP AND BOTTOM INTERNAL EDGE
-		for(j = half_kernel; j < ncol_h;j++){
-			for(i = 0; i < half_kernel; i++) *(mat_max.begin() + i+col_vec[j]) = *(mat_max.begin() + half_kernel+col_vec[j]);
-			for(i = nrow_h; i < nrow; i++) *(mat_max.begin() + i+col_vec[j]) = *(mat_max.begin() + nrow_h-1+col_vec[j]);
+		for(j = half_k; j < ncol_h;j++){
+			for(i = 0; i < half_k; i++) *(mat_max.begin() + i+j*nrow) = *(mat_max.begin() + half_k+j*nrow);
+			for(i = nrow_h; i < nrow; i++) *(mat_max.begin() + i+j*nrow) = *(mat_max.begin() + nrow_h-1+j*nrow);
 		}
 
 		// SET MAX KERNEL VALUES ALONG LEFT AND RIGHT EDGE
 		for(i = 0; i < nrow; i++){
-			for(j = 0; j < half_kernel;j++) *(mat_max.begin() + i+col_vec[j]) = *(mat_max.begin() + i+col_vec[half_kernel]);
-			for(j = ncol_h; j < ncol;j++) *(mat_max.begin() + i+col_vec[j]) = *(mat_max.begin() + i+col_vec[ncol_h-1]);
+			for(j = 0; j < half_k;j++) *(mat_max.begin() + i+j*nrow) = *(mat_max.begin() + i+half_k*nrow);
+			for(j = ncol_h; j < ncol;j++) *(mat_max.begin() + i+j*nrow) = *(mat_max.begin() + i+(ncol_h-1)*nrow);
 		}
 		
 		if(it < niter - 1) std::copy(mat_max.begin(), mat_max.end(), mat_copy.begin());
